define('dummy/components/ui-bs-button-choice', ['exports', 'ember'], function (exports, Ember) {

	'use strict';

	var isEmpty = Ember['default'].isEmpty;
	var typeOf = Ember['default'].typeOf;

	exports['default'] = Ember['default'].Component.extend({
		// Component Properties
		tagName: "div",
		classNames: ["ui-bs-button-choice", "btn-group"],
		attributeBindings: ["dataToggle:data-toggle"],
		dataToggle: "buttons",
		// Data Properties
		choices: null,
		labelProp: "name", // the property name to display when given a hash
		valueProp: "id", // the property name to use as a reference key when given a hash
		type: "radio", // radio/checkbox
		missingChoicesText: "no choices available",
		canBeNull: null,
		_canBeNull: (function () {
			Ember['default'].run.next(this, function () {
				if (this.get("canBeNull") === null) {
					this.set("canBeNull", this.get("type") === "radio" ? false : true);
				}
			});
		}).on("didInsertElement"),
		color: "default",
		colorClass: (function () {
			return "btn-%@".fmt(this.get("color"));
		}).property("color"),
		size: "default",
		sizeClass: (function () {
			var size = this.get("size");
			if (["lg", "large"].contains(size)) {
				return "btn-lg";
			} else if (["sm", "small"].contains(size)) {
				return "btn-sm";
			} else if (["xs", "tiny"].contains(size)) {
				return "btn-xs";
			} else {
				return false;
			}
		}).property("size"),
		selected: null,
		selectedObject: null,
		choicesHash: [],
		/**
	 	Set the `choicesHash` to the appropriate value. Choices will come in as one of the following formats:
	 
	 	1) An array of objects (the easiest to deal with)
	 	2) An array of literals (numbers or strings)
	 	3) A comma seperated string (which is just converted to #1)
	 	4) A deferred array of objects such as a Promise or specifically an Ember-Data Promise
	 	5) A deferred object which has an offset/deep property of which contains the array
	 
	 	In all cases the aim is to set "choicesHash" to format #1
	 */
		_choicesHash: (function () {
			Ember['default'].run.next(this, function () {
				var self = this;
				var p = this.getProperties("choices", "labelProp", "valueProp", "type", "selected");
				if (typeOf(p.choices) === "string") {
					p.choices = p.choices.split(",");
				}
				if (isEmpty(p.choices)) {
					this.set("choicesHash", []);
					return;
				}
				// is it an Ember promise?
				if (["class", "instance"].contains(typeOf(p.choices))) {
					if (p.choices.isFulfilled) {
						p.choices = p.choices.get("content");
						p.choices = this.processPromise(p.choices);
					} else {
						console.log("%s not yet fulfilled", this.get("elementId"));
						p.choices.then(function (promisedChoices) {
							console.log("promise has been fulfilled: %o", promisedChoices);
							promisedChoices = self.processPromise(promisedChoices);
							console.log("choices promised: %o", promisedChoices);
							self.processChoiceHash(promisedChoices, p.selected, { valueProp: p.valueProp, labelProp: p.labelProp });
						});
					}
				}
				this.set("choicesHash", this.processChoiceHash(p.choices, p.selected, { valueProp: p.valueProp, labelProp: p.labelProp }));
			});
		}).observes("choices.length", "selected").on("didInsertElement"),
		processChoiceHash: function (choices, selected, options) {
			if (typeOf(choices) === "array") {
				var choicesHash = choices.map(function (item, index) {
					var hash;
					if (["string", "number"].contains(typeOf(item))) {
						hash = {};
						hash.id = String(item);
						hash.name = String(item);
					} else {
						// copy object
						hash = JSON.parse(JSON.stringify(item));
						// ensure interface is met
						hash.id = String(item[options.valueProp]);
						hash.name = String(item[options.labelProp]);
					}
					// Selected?
					if (typeOf(selected) === "array" && selected.contains(hash.id) || typeOf(selected) === "string" && selected === hash.id) {
						hash.checked = true;
					}

					return hash;
				});
				if (isEmpty(choicesHash.filterBy("checked", true)) && !this.get("canBeNull")) {
					choicesHash[0].checked = true;
					this.set("selected", choicesHash[0].id);
				}

				return choicesHash;
			} else {
				return [];
			}
		},
		processPromise: function (promise) {
			if (promise.id) {
				var choicesOffset = this.get("choicesOffset");
				if (choicesOffset) {
					// an explicit statement about what property to use is available
					promise = promise._data[choicesOffset];
				} else {
					console.warn("%s retrieved a promise object but no offset property was provided to populate the choices.", this.get("elementId"));
					promise = [];
				}
			} else {
				promise = promise.get("content").map(function (item) {
					return item._data;
				});
			}
			return promise;
		},
		click: function (evt) {
			Ember['default'].run.next(this, function () {
				var action = this.processEvent();
				if (action.hasChanged) {
					this.set("selected", action.selected);
					this.set("selectedObject", action.selectedObject);
					this.sendAction("changeEvent", action);
				} else if (this.get("canBeNull")) {
					this.set("selected", null);
					this.set("selectedObject", null);
				}
			});
		},
		processEvent: function () {
			var selected;
			var selectedObject;
			var self = this;
			if (this.get("type") === "radio") {
				selected = this.$(".active input").val();
				selectedObject = this.get("choicesHash").findBy("id", selected);
			} else {
				selected = [];
				selectedObject = [];
				this.$(".active input").each(function () {
					var newItem = $(this).val();
					selected.pushObject(newItem);
					selectedObject.pushObject(self.get("choicesHash").findBy("id", newItem));
				});
			}
			// determine the change (if any)
			var componentState = this.getProperties("selected", "selectedObject");
			var type = this.get("type");
			var state = {
				isEmpty: null,
				howMany: null,
				hasChanged: null, // maybe be overridden below
				changeSource: null, // [external,bootstrap]
				added: [], // list of ID(s) just added
				removed: [] // list of ID(s) just removed
			};
			// radio versus checkbox
			if (type === "radio") {
				// existance
				if (isEmpty(selected)) {
					state.isEmpty = true;
					state.howMany = 0;
				} else {
					state.isEmpty = false;
					state.howMany = 1;
				}
				// changes
				if (componentState.selected !== selected) {
					state.hasChanged = true;
					state.changeSource = "bootstrap";
					if (!state.isEmpty) {
						state.added = [selected];
					}
					if (!Ember['default'].isEmpty(componentState.selected)) {
						state.removed = [componentState.selected];
					}
				} else {
					// if change was done directly to "selected" bound property
					// we will end up in this state but there will be delta in selectedObject
					if (isEmpty(componentState.selectedObject) || componentState.selectedObject.id !== selectedObject.id) {
						state.hasChanged = true;
						state.changeSource = "external";
						if (!isEmpty(selectedObject)) {
							state.added = [selectedObject.id];
						}
						if (!isEmpty(componentState.selectedObject)) {
							state.removed = [componentState.selectedObject.id];
						}
					} else {
						state.hasChanged = false;
					}
				}
			} else {
				// existance
				if (Ember['default'].isEmpty(selected)) {
					state.isEmpty = true;
					state.howMany = 0;
				} else {
					state.isEmpty = false;
					state.howMany = selected.length;
				}
				// changes
				componentState.selected = isEmpty(componentState.selected) ? [] : componentState.selected;
				if (typeOf(componentState.selected) === "string") {
					// a checkbox's should always be a selector but if its a string then convert gracefully and warn to console
					componentState.selected = componentState.selected.split(",");
				}
				selected = selected || [];
				if (componentState.selected.join(",") !== selected.join(",")) {
					state.hasChanged = true;
					state.changeSource = "bootstrap";
					componentState.selected.forEach(function (item, index) {
						if (!selected.contains(item)) {
							state.removed.addObject(item);
						}
					});
					selected.forEach(function (item, index) {
						if (!componentState.selected.contains(item)) {
							state.added.addObject(item);
						}
					});
				} else {
					// if change was done directly to "selected" bound property
					// we will end up in this state but there will be delta in selectedObject
					componentState.selectedObject = componentState.selectedObject || [];
					if (componentState.selectedObject.mapBy("id").join(",") !== selectedObject.mapBy("id").join(",")) {
						state.hasChanged = true;
						state.changeSource = "external";
						if (!isEmpty(selectedObject)) {
							selectedObject.mapBy("id").forEach(function (item, index) {
								if (!componentState.selectedObject.mapBy("id").contains(item)) {
									state.added.addObject(item);
								}
							});
							componentState.selectedObject.mapBy("id").forEach(function (item, index) {
								if (!selectedObject.mapBy("id").contains(item)) {
									state.removed.addObject(item);
								}
							});
						}
						if (!isEmpty(componentState.selectedObject)) {
							state.removed = [componentState.selectedObject.id];
						}
					} else {
						state.hasChanged = false;
					}
				}
			}
			// handle no selections if not allowed
			if (!this.get("canBeNull") && state.isEmpty) {
				// TODO: implement
				console.log("property that can not be null, IS.");
			}
			state.selected = selected;
			state.selectedObject = selectedObject;
			return state;
		},
		selectedObserver: (function () {
			Ember['default'].run.next(this, function () {
				var action = this.processEvent();
				if (action.hasChanged) {
					this.set("selectedObject", action.selectedObject);
				}
			});
		}).observes("selected")
	});

});