define('dummy/app', ['exports', 'ember', 'ember/resolver', 'ember/load-initializers', './config/environment'], function (exports, Ember, Resolver, loadInitializers, config) {

  'use strict';

  Ember['default'].MODEL_FACTORY_INJECTIONS = true;

  var App = Ember['default'].Application.extend({
    modulePrefix: config['default'].modulePrefix,
    podModulePrefix: config['default'].podModulePrefix,
    Resolver: Resolver['default']
  });

  loadInitializers['default'](App, config['default'].modulePrefix);

  exports['default'] = App;

});
define('dummy/components/ui-bs-button-choice', ['exports', 'ember'], function (exports, Ember) {

	'use strict';

	var isEmpty = Ember['default'].isEmpty;
	var typeOf = Ember['default'].typeOf;

	exports['default'] = Ember['default'].Component.extend({
		// Component Properties
		tagName: "div",
		classNames: ["ui-bs-button-choice", "btn-group"],
		attributeBindings: ["dataToggle:data-toggle"],
		dataToggle: "buttons",
		// Data Properties
		choices: null,
		labelProp: "name", // the property name to display when given a hash
		valueProp: "id", // the property name to use as a reference key when given a hash
		type: "radio", // radio/checkbox
		missingChoicesText: "no choices available",
		canBeNull: null,
		_canBeNull: (function () {
			Ember['default'].run.next(this, function () {
				if (this.get("canBeNull") === null) {
					this.set("canBeNull", this.get("type") === "radio" ? false : true);
				}
			});
		}).on("didInsertElement"),
		color: "default",
		colorClass: (function () {
			return "btn-%@".fmt(this.get("color"));
		}).property("color"),
		size: "default",
		sizeClass: (function () {
			var size = this.get("size");
			if (["lg", "large"].contains(size)) {
				return "btn-lg";
			} else if (["sm", "small"].contains(size)) {
				return "btn-sm";
			} else if (["xs", "tiny"].contains(size)) {
				return "btn-xs";
			} else {
				return false;
			}
		}).property("size"),
		selected: null,
		selectedObject: null,
		choicesHash: [],
		/**
	 	Set the `choicesHash` to the appropriate value. Choices will come in as one of the following formats:
	 
	 	1) An array of objects (the easiest to deal with)
	 	2) An array of literals (numbers or strings)
	 	3) A comma seperated string (which is just converted to #1)
	 	4) A deferred array of objects such as a Promise or specifically an Ember-Data Promise
	 	5) A deferred object which has an offset/deep property of which contains the array
	 
	 	In all cases the aim is to set "choicesHash" to format #1
	 */
		_choicesHash: (function () {
			Ember['default'].run.next(this, function () {
				var self = this;
				var p = this.getProperties("choices", "labelProp", "valueProp", "type", "selected");
				if (typeOf(p.choices) === "string") {
					p.choices = p.choices.split(",");
				}
				if (isEmpty(p.choices)) {
					this.set("choicesHash", []);
					return;
				}
				// is it an Ember promise?
				if (["class", "instance"].contains(typeOf(p.choices))) {
					if (p.choices.isFulfilled) {
						p.choices = p.choices.get("content");
						p.choices = this.processPromise(p.choices);
					} else {
						console.log("%s not yet fulfilled", this.get("elementId"));
						p.choices.then(function (promisedChoices) {
							console.log("promise has been fulfilled: %o", promisedChoices);
							promisedChoices = self.processPromise(promisedChoices);
							console.log("choices promised: %o", promisedChoices);
							self.processChoiceHash(promisedChoices, p.selected, { valueProp: p.valueProp, labelProp: p.labelProp });
						});
					}
				}
				this.set("choicesHash", this.processChoiceHash(p.choices, p.selected, { valueProp: p.valueProp, labelProp: p.labelProp }));
			});
		}).observes("choices.length", "selected").on("didInsertElement"),
		processChoiceHash: function (choices, selected, options) {
			if (typeOf(choices) === "array") {
				var choicesHash = choices.map(function (item, index) {
					var hash;
					if (["string", "number"].contains(typeOf(item))) {
						hash = {};
						hash.id = String(item);
						hash.name = String(item);
					} else {
						// copy object
						hash = JSON.parse(JSON.stringify(item));
						// ensure interface is met
						hash.id = String(item[options.valueProp]);
						hash.name = String(item[options.labelProp]);
					}
					// Selected?
					if (typeOf(selected) === "array" && selected.contains(hash.id) || typeOf(selected) === "string" && selected === hash.id) {
						hash.checked = true;
					}

					return hash;
				});
				if (isEmpty(choicesHash.filterBy("checked", true)) && !this.get("canBeNull")) {
					choicesHash[0].checked = true;
					this.set("selected", choicesHash[0].id);
				}

				return choicesHash;
			} else {
				return [];
			}
		},
		processPromise: function (promise) {
			if (promise.id) {
				var choicesOffset = this.get("choicesOffset");
				if (choicesOffset) {
					// an explicit statement about what property to use is available
					promise = promise._data[choicesOffset];
				} else {
					console.warn("%s retrieved a promise object but no offset property was provided to populate the choices.", this.get("elementId"));
					promise = [];
				}
			} else {
				promise = promise.get("content").map(function (item) {
					return item._data;
				});
			}
			return promise;
		},
		click: function (evt) {
			Ember['default'].run.next(this, function () {
				var action = this.processEvent();
				if (action.hasChanged) {
					this.set("selected", action.selected);
					this.set("selectedObject", action.selectedObject);
					this.sendAction("changeEvent", action);
				} else if (this.get("canBeNull")) {
					this.set("selected", null);
					this.set("selectedObject", null);
				}
			});
		},
		processEvent: function () {
			var selected;
			var selectedObject;
			var self = this;
			if (this.get("type") === "radio") {
				selected = this.$(".active input").val();
				selectedObject = this.get("choicesHash").findBy("id", selected);
			} else {
				selected = [];
				selectedObject = [];
				this.$(".active input").each(function () {
					var newItem = $(this).val();
					selected.pushObject(newItem);
					selectedObject.pushObject(self.get("choicesHash").findBy("id", newItem));
				});
			}
			// determine the change (if any)
			var componentState = this.getProperties("selected", "selectedObject");
			var type = this.get("type");
			var state = {
				isEmpty: null,
				howMany: null,
				hasChanged: null, // maybe be overridden below
				changeSource: null, // [external,bootstrap]
				added: [], // list of ID(s) just added
				removed: [] // list of ID(s) just removed
			};
			// radio versus checkbox
			if (type === "radio") {
				// existance
				if (isEmpty(selected)) {
					state.isEmpty = true;
					state.howMany = 0;
				} else {
					state.isEmpty = false;
					state.howMany = 1;
				}
				// changes
				if (componentState.selected !== selected) {
					state.hasChanged = true;
					state.changeSource = "bootstrap";
					if (!state.isEmpty) {
						state.added = [selected];
					}
					if (!Ember['default'].isEmpty(componentState.selected)) {
						state.removed = [componentState.selected];
					}
				} else {
					// if change was done directly to "selected" bound property
					// we will end up in this state but there will be delta in selectedObject
					if (isEmpty(componentState.selectedObject) || componentState.selectedObject.id !== selectedObject.id) {
						state.hasChanged = true;
						state.changeSource = "external";
						if (!isEmpty(selectedObject)) {
							state.added = [selectedObject.id];
						}
						if (!isEmpty(componentState.selectedObject)) {
							state.removed = [componentState.selectedObject.id];
						}
					} else {
						state.hasChanged = false;
					}
				}
			} else {
				// existance
				if (Ember['default'].isEmpty(selected)) {
					state.isEmpty = true;
					state.howMany = 0;
				} else {
					state.isEmpty = false;
					state.howMany = selected.length;
				}
				// changes
				componentState.selected = isEmpty(componentState.selected) ? [] : componentState.selected;
				if (typeOf(componentState.selected) === "string") {
					// a checkbox's should always be a selector but if its a string then convert gracefully and warn to console
					componentState.selected = componentState.selected.split(",");
				}
				selected = selected || [];
				if (componentState.selected.join(",") !== selected.join(",")) {
					state.hasChanged = true;
					state.changeSource = "bootstrap";
					componentState.selected.forEach(function (item, index) {
						if (!selected.contains(item)) {
							state.removed.addObject(item);
						}
					});
					selected.forEach(function (item, index) {
						if (!componentState.selected.contains(item)) {
							state.added.addObject(item);
						}
					});
				} else {
					// if change was done directly to "selected" bound property
					// we will end up in this state but there will be delta in selectedObject
					componentState.selectedObject = componentState.selectedObject || [];
					if (componentState.selectedObject.mapBy("id").join(",") !== selectedObject.mapBy("id").join(",")) {
						state.hasChanged = true;
						state.changeSource = "external";
						if (!isEmpty(selectedObject)) {
							selectedObject.mapBy("id").forEach(function (item, index) {
								if (!componentState.selectedObject.mapBy("id").contains(item)) {
									state.added.addObject(item);
								}
							});
							componentState.selectedObject.mapBy("id").forEach(function (item, index) {
								if (!selectedObject.mapBy("id").contains(item)) {
									state.removed.addObject(item);
								}
							});
						}
						if (!isEmpty(componentState.selectedObject)) {
							state.removed = [componentState.selectedObject.id];
						}
					} else {
						state.hasChanged = false;
					}
				}
			}
			// handle no selections if not allowed
			if (!this.get("canBeNull") && state.isEmpty) {
				// TODO: implement
				console.log("property that can not be null, IS.");
			}
			state.selected = selected;
			state.selectedObject = selectedObject;
			return state;
		},
		selectedObserver: (function () {
			Ember['default'].run.next(this, function () {
				var action = this.processEvent();
				if (action.hasChanged) {
					this.set("selectedObject", action.selectedObject);
				}
			});
		}).observes("selected")
	});

});
define('dummy/controllers/application', ['exports', 'ember', 'pretender'], function (exports, Ember, Pretender) {

	'use strict';

	exports['default'] = Ember['default'].Controller.extend({

		boundArray: ["one", "two", "three"],
		boundHash: [{ id: "one", name: "One", sidecar: "foo" }, { id: "two", name: "Two", sidecar: "bar" }, { id: "three", name: "Three", sidecar: "baz" }],
		selector: "three",
		dynArray: ["one", "two"],
		dynHashArray: [{ id: "1", name: "One" }, { id: "2", name: "Two" }],
		promisedArray: (function () {
			return this.get("store").find("color");
		}).property(),
		promisedObject: (function () {
			return this.get("store").find("animal", "mammal");
		}).property(),
		actions: {
			handleRadioChange: function (change) {
				window.alert("Change to radio control. Current selection is \"%@\". Source was %@.".fmt(change.selected, change.changeSource));
			},
			addArrayElement: function () {
				var current = this.get("dynArray");
				current.addObject(String(current.length + 1));
			},
			removeArrayElement: function () {
				var current = this.get("dynArray");
				if (current.length > 0) {
					this.set("dynArray", current.slice(0, current.length - 1));
				}
			},
			addHashElement: function () {
				var current = this.get("dynHashArray");
				var randomName = function () {
					var randomChoices = ["foo", "bar", "baz", "monkey", "boo", "berry"];
					var seed = Math.floor(Math.random() * (randomChoices.length - 1)) + 1;
					return randomChoices[seed];
				};
				current.addObject({ id: current.length + 1, name: randomName() });
			},
			addSimpleToHashElement: function () {
				var current = this.get("dynHashArray");
				current.addObject(String(current.length + 1));
			},
			removeHashElement: function () {
				var current = this.get("dynHashArray");
				var reduced = current.slice(0, current.length - 1);
				this.set("dynHashArray", reduced);
			}
		},
		server: null,
		startupServer: (function () {
			var self = this;
			var promisedArray = {
				colors: [{ id: "red", name: "Red", group: "primary" }, { id: "blue", name: "Blue", group: "primary" }, { id: "green", name: "Green", group: "primary" }] };
			var promisedObject = { animal: { id: "mammal", examples: ["lion", "bear", "tiger"] } };
			self.set("server", new Pretender['default'](function () {
				this.get("/colors", function (request) {
					return [200, { "Content-Type": "application/json" }, JSON.stringify(promisedArray)];
				}, 5000);
				this.get("/animals/:id", function (request) {
					return [200, { "Content-Type": "application/json" }, JSON.stringify(promisedObject)];
				}, 5000);
			}));
		}).on("init"),
		teardownServer: (function () {
			this.get("server").shutdown();
		}).on("willDestroy")


	});

});
define('dummy/initializers/export-application-global', ['exports', 'ember', '../config/environment'], function (exports, Ember, config) {

  'use strict';

  exports.initialize = initialize;

  function initialize(container, application) {
    var classifiedName = Ember['default'].String.classify(config['default'].modulePrefix);

    if (config['default'].exportApplicationGlobal) {
      window[classifiedName] = application;
    }
  };

  exports['default'] = {
    name: "export-application-global",

    initialize: initialize
  };
  exports.__esModule = true;

});
define('dummy/models/animal', ['exports', 'ember-data'], function (exports, DS) {

	'use strict';

	var attr = DS['default'].attr;

	exports['default'] = DS['default'].Model.extend({
		// The 'giver' and 'taker' are users and the role they have WRT to permissions/visibility
		name: attr("string"),
		group: attr("string"),
		examples: attr("array")
	});

});
define('dummy/models/color', ['exports', 'ember-data'], function (exports, DS) {

	'use strict';

	var attr = DS['default'].attr;

	exports['default'] = DS['default'].Model.extend({
		// The 'giver' and 'taker' are users and the role they have WRT to permissions/visibility
		name: attr("string"),
		group: attr("string")
	});

});
define('dummy/router', ['exports', 'ember', './config/environment'], function (exports, Ember, config) {

  'use strict';

  var Router = Ember['default'].Router.extend({
    location: config['default'].locationType
  });

  Router.map(function () {});

  exports['default'] = Router;

});
define('dummy/templates/application', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  exports['default'] = Ember['default'].Handlebars.template(function anonymous(Handlebars,depth0,helpers,partials,data) {
  this.compilerInfo = [4,'>= 1.0.0'];
  helpers = this.merge(helpers, Ember['default'].Handlebars.helpers); data = data || {};
    var buffer = '', stack1, helper, options, helperMissing=helpers.helperMissing, escapeExpression=this.escapeExpression;


    data.buffer.push("<h1 id='title'>ui-bs-button-choice</h1>\n<h4>Enumerated choice dialog using Boostrap buttons</h4>\n<hr>\n<h5>Test Data</h5>\n<pre>\ncontroller: {\n	boundArray: ['one','two','three'],\n	boundHash: [\n		{id: 'one', name: 'One', sidecar: 'foo'},\n		{id: 'two', name: 'Two', sidecar: 'bar'},\n		{id: 'three', name: 'Three', sidecar: 'baz'}\n	],\n	selector: 'three',\n	dynArray: ['one','two'],\n	dynHashArray: [{id:1, name:'One'}, {id:2, name:'Two'}]\n}\n</pre>\n\n<hr>\n<h5>Radio Selectors</h5>\n<table class=\"demo-table\">\n	<tr>\n		<td class=\"col-xs-4\">\n			");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("one,two,three")
    },hashTypes:{'choices': "STRING"},hashContexts:{'choices': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n		</td>\n		<td class=\"col-xs-8\">\n			static, comma-delimited options<br/>\n			<code>\n{{ui-bs-button-choice choices='one,two,three'}}\n			</code>\n		</td>\n	</tr>\n	<tr>\n		<td class=\"col-xs-4\">\n			");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("one,two,three"),
      'selected': ("two")
    },hashTypes:{'choices': "STRING",'selected': "STRING"},hashContexts:{'choices': depth0,'selected': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n		</td>\n		<td class=\"col-xs-8\">\n			static, comma-delimited options, value code-selected<br/>\n			<code>\n{{ui-bs-button-choice choices='one,two,three' selected='two'}}\n			</code>\n		</td>\n	</tr>\n	<tr>\n		<td class=\"col-xs-4\">\n			");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("boundArray")
    },hashTypes:{'choices': "ID"},hashContexts:{'choices': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n		</td>\n		<td class=\"col-xs-8\">\n			a bound array of values<br/>\n			<code>\n{{ui-bs-button-choice choices=boundArray}}\n			</code>\n		</td>\n	</tr>\n	<tr>\n		<td class=\"col-xs-4\">\n			");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("boundHash")
    },hashTypes:{'choices': "ID"},hashContexts:{'choices': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n		</td>\n		<td class=\"col-xs-8\">\n			a bound array of objects<br/>\n			<code>\n{{ui-bs-button-choice choices=boundHash}}\n			</code>\n		</td>\n	</tr>\n	<tr>\n		<td class=\"col-xs-4\">\n			");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("one,two,three"),
      'canBeNull': ("true")
    },hashTypes:{'choices': "STRING",'canBeNull': "STRING"},hashContexts:{'choices': depth0,'canBeNull': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n		</td>\n		<td class=\"col-xs-8\">\n			null IS allowed, no selected value set<br/>\n			<code>\n{{ui-bs-button-choice choices=boundArray canBeNull='true'}}\n			</code>\n		</td>\n	</tr>\n	\n	<tr>\n		<td class=\"col-xs-4\">\n			");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("boundHash"),
      'labelProp': ("sidecar")
    },hashTypes:{'choices': "ID",'labelProp': "STRING"},hashContexts:{'choices': depth0,'labelProp': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n		</td>\n		<td class=\"col-xs-8\">\n			a bound array of objects, using explicit label<br/>\n			<code>\n{{ui-bs-button-choice choices=boundHash labelProp='sidecar'}}\n			</code>\n		</td>\n	</tr>\n	<tr>\n		<td class=\"col-xs-4\">\n			");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("boundHash"),
      'selected': ("selector")
    },hashTypes:{'choices': "ID",'selected': "ID"},hashContexts:{'choices': depth0,'selected': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n		</td>\n		<td class=\"col-xs-8\">\n			bound selector preset to 'three' [currently: ");
    stack1 = helpers._triageMustache.call(depth0, "selector", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["ID"],data:data});
    if(stack1 || stack1 === 0) { data.buffer.push(stack1); }
    data.buffer.push("]<br/>\n			<code>\n{{ui-bs-button-choice choices=boundHash selected=selector}}\n			</code>\n		</td>\n	</tr>\n	<tr>\n		<td class=\"col-xs-4\">\n			");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'changeEvent': ("handleRadioChange"),
      'choices': ("boundHash")
    },hashTypes:{'changeEvent': "STRING",'choices': "ID"},hashContexts:{'changeEvent': depth0,'choices': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n		</td>\n		<td class=\"col-xs-8\">\n			bound to changeEvent<br/>\n			<code>\n{{ui-bs-button-choice changeEvent='handleRadioChange' choices=boundHash}}\n			</code>\n		</td>\n	</tr>	\n</table>\n\n<hr>\n<h5>Checkbox Selectors</h5>\n<div class=\"checkbox-tests\">\n	<table class=\"demo-table\">\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("one,two,three"),
      'type': ("checkbox")
    },hashTypes:{'choices': "STRING",'type': "STRING"},hashContexts:{'choices': depth0,'type': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				static, comma-delimited set of options<br/>\n				<code>\n	{{ui-bs-button-choice choices='one,two,three' type='checkbox'}}\n				</code>\n			</td>\n		</tr>\n	</table>\n</div>\n\n<hr>\n<h5>Promise/Deferred Data</h5>\n<pre>\nserver: null,\nstartupServer: function() {\n	var self = this;\n	var promisedArray = { \n		colors: [\n			{id:\"red\", name:\"Red\", group:\"primary\"},\n			{id:\"blue\", name:\"Blue\", group:\"primary\"},\n			{id:\"green\", name:\"Green\", group:\"primary\"},\n	]};\n	var promisedObject = { animal: {id:\"mammal\", examples:['lion','tiger','bear']} };\n	self.set('server', new Pretender(function(){\n	  this.get('/colors', function(request){\n		  return [200, {\"Content-Type\": \"application/json\"}, JSON.stringify(promisedArray)];\n	  }, 5000);\n	  this.get('/animals/:id', function(request){\n		  return [200, {\"Content-Type\": \"application/json\"}, JSON.stringify(promisedObject)];\n	  }, 5000);\n	}));		\n}\n</pre>\n\n<div id=\"promise-tests\">\n	<table class=\"demo-table\">\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("promisedArray")
    },hashTypes:{'choices': "ID"},hashContexts:{'choices': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				Ember-data list/array returned<br/>\n				<code>\n	{{ui-bs-button-choice choices=promisedArray }}\n				</code>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("promisedObject"),
      'choicesOffset': ("examples")
    },hashTypes:{'choices': "ID",'choicesOffset': "STRING"},hashContexts:{'choices': depth0,'choicesOffset': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				Ember-data returns object w/ array property<br/>\n				<code>\n	{{ui-bs-button-choice choices=promisedObject choicesOffset='examples'}}\n				</code>\n			</td>\n		</tr>\n	</table>\n</div>\n\n\n<hr>\n<h5>Other Tests</h5>\n<div id=\"other-tests\">\n\n	<table class=\"demo-table\">\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    stack1 = helpers._triageMustache.call(depth0, "ui-bs-button-choice", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["ID"],data:data});
    if(stack1 || stack1 === 0) { data.buffer.push(stack1); }
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				No choices provided<br/>\n				<code>\n	{{ui-bs-button-choice}}\n				</code>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'missingChoicesText': ("you have nothing!")
    },hashTypes:{'missingChoicesText': "STRING"},hashContexts:{'missingChoicesText': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				No choices provided, bespoke text<br/>\n				<code>\n	{{ui-bs-button-choice missingChoicesText='you have nothing!'}}\n				</code>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("dynArray"),
      'size': ("small")
    },hashTypes:{'choices': "ID",'size': "STRING"},hashContexts:{'choices': depth0,'size': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				dynamic choice modification to simple choices array<br/>\n				<button class=\"btn btn-default btn-sm\"");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "addArrayElement", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["STRING"],data:data})));
    data.buffer.push(">Add</button>\n				<button class=\"btn btn-default btn-sm\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "removeArrayElement", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["STRING"],data:data})));
    data.buffer.push(">Remove</button><br/>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("dynHashArray"),
      'size': ("small")
    },hashTypes:{'choices': "ID",'size': "STRING"},hashContexts:{'choices': depth0,'size': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				dynamic choice with hash choice array (<code>dynHashArray</code>)<br/>\n				<button class=\"btn btn-default btn-sm\"");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "addHashElement", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["STRING"],data:data})));
    data.buffer.push(">Add</button>\n				<button class=\"btn btn-default btn-sm\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "removeHashElement", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["STRING"],data:data})));
    data.buffer.push(">Remove</button><br/>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("dynHashArray"),
      'size': ("small")
    },hashTypes:{'choices': "ID",'size': "STRING"},hashContexts:{'choices': depth0,'size': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				adding simple element into hash choice array (<code>dynHashArray</code>)<br/>\n				<button class=\"btn btn-default btn-sm\"");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "addSimpleToHashElement", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["STRING"],data:data})));
    data.buffer.push(">Add</button>\n				<button class=\"btn btn-default btn-sm\" ");
    data.buffer.push(escapeExpression(helpers.action.call(depth0, "removeHashElement", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["STRING"],data:data})));
    data.buffer.push(">Remove</button><br/>\n			</td>\n		</tr>\n	\n	</table>\n</div>\n\n\n<hr>\n<h5>Formatting Tests</h5>\n<div id=\"formatting-tests\">\n	<table class=\"demo-table\">\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("one,two,three"),
      'color': ("warning"),
      'type': ("checkbox")
    },hashTypes:{'choices': "STRING",'color': "STRING",'type': "STRING"},hashContexts:{'choices': depth0,'color': depth0,'type': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				checkbox using warning color<br/>\n				<code>\n	{{ui-bs-button-choice choices=boundArray color='warning' type='checkbox'}}\n				</code>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'choices': ("one,two,three"),
      'color': ("primary")
    },hashTypes:{'choices': "STRING",'color': "STRING"},hashContexts:{'choices': depth0,'color': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				radio using primary color<br/>\n				<code>\n	{{ui-bs-button-choice choices='one,two,three' color='primary'}}\n				</code>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'size': ("large"),
      'choices': ("one,two")
    },hashTypes:{'size': "STRING",'choices': "STRING"},hashContexts:{'size': depth0,'choices': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				big buttons<br/>\n				<code>\n	{{ui-bs-button-choice size='large' choices='one,two'}}\n				</code>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'size': ("small"),
      'choices': ("one,two,three,four")
    },hashTypes:{'size': "STRING",'choices': "STRING"},hashContexts:{'size': depth0,'choices': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				small buttons<br/>\n				<code>\n	{{ui-bs-button-choice size='small' choices='one,two,three,four'}}\n				</code>\n			</td>\n		</tr>\n		<tr>\n			<td class=\"col-xs-4\">\n				");
    data.buffer.push(escapeExpression((helper = helpers['ui-bs-button-choice'] || (depth0 && depth0['ui-bs-button-choice']),options={hash:{
      'size': ("tiny"),
      'choices': ("one,two,three,four,five")
    },hashTypes:{'size': "STRING",'choices': "STRING"},hashContexts:{'size': depth0,'choices': depth0},contexts:[],types:[],data:data},helper ? helper.call(depth0, options) : helperMissing.call(depth0, "ui-bs-button-choice", options))));
    data.buffer.push("\n			</td>\n			<td class=\"col-xs-8\">\n				tiny buttons<br/>\n				<code>\n	{{ui-bs-button-choice size='tiny' choices='one,two,three,four,five' }}\n				</code>\n			</td>\n		</tr>\n\n	</table>\n</div>\n\n");
    return buffer;
    
  });

});
define('dummy/templates/components/ui-bs-button-choice', ['exports', 'ember'], function (exports, Ember) {

  'use strict';

  exports['default'] = Ember['default'].Handlebars.template(function anonymous(Handlebars,depth0,helpers,partials,data) {
  this.compilerInfo = [4,'>= 1.0.0'];
  helpers = this.merge(helpers, Ember['default'].Handlebars.helpers); data = data || {};
    var buffer = '', stack1, escapeExpression=this.escapeExpression, self=this;

  function program1(depth0,data) {
    
    var buffer = '', stack1;
    data.buffer.push("\n	<label ");
    data.buffer.push(escapeExpression(helpers['bind-attr'].call(depth0, {hash:{
      'class': (":btn colorClass sizeClass choice.checked:active")
    },hashTypes:{'class': "STRING"},hashContexts:{'class': depth0},contexts:[],types:[],data:data})));
    data.buffer.push(">\n		<input ");
    data.buffer.push(escapeExpression(helpers['bind-attr'].call(depth0, {hash:{
      'type': ("type")
    },hashTypes:{'type': "ID"},hashContexts:{'type': depth0},contexts:[],types:[],data:data})));
    data.buffer.push(" id=\"");
    data.buffer.push(escapeExpression(helpers.unbound.call(depth0, "elementId", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["ID"],data:data})));
    data.buffer.push("-");
    data.buffer.push(escapeExpression(helpers.unbound.call(depth0, "choice.id", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["ID"],data:data})));
    data.buffer.push("\" name=\"options\" autocomplete=\"off\" ");
    data.buffer.push(escapeExpression(helpers['bind-attr'].call(depth0, {hash:{
      'value': ("choice.id")
    },hashTypes:{'value': "ID"},hashContexts:{'value': depth0},contexts:[],types:[],data:data})));
    data.buffer.push(">");
    stack1 = helpers._triageMustache.call(depth0, "choice.name", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["ID"],data:data});
    if(stack1 || stack1 === 0) { data.buffer.push(stack1); }
    data.buffer.push("\n	</label>\n");
    return buffer;
    }

  function program3(depth0,data) {
    
    var buffer = '', stack1;
    data.buffer.push("\n	<span class=\"missing-choices\">\n		");
    stack1 = helpers._triageMustache.call(depth0, "missingChoicesText", {hash:{},hashTypes:{},hashContexts:{},contexts:[depth0],types:["ID"],data:data});
    if(stack1 || stack1 === 0) { data.buffer.push(stack1); }
    data.buffer.push("\n	</span>\n");
    return buffer;
    }

    stack1 = helpers.each.call(depth0, "choice", "in", "choicesHash", {hash:{},hashTypes:{},hashContexts:{},inverse:self.program(3, program3, data),fn:self.program(1, program1, data),contexts:[depth0,depth0,depth0],types:["ID","ID","ID"],data:data});
    if(stack1 || stack1 === 0) { data.buffer.push(stack1); }
    data.buffer.push("\n");
    return buffer;
    
  });

});
define('dummy/tests/app.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('app.js should pass jshint', function() { 
    ok(true, 'app.js should pass jshint.'); 
  });

});
define('dummy/tests/controllers/application.jshint', function () {

  'use strict';

  module('JSHint - controllers');
  test('controllers/application.js should pass jshint', function() { 
    ok(true, 'controllers/application.js should pass jshint.'); 
  });

});
define('dummy/tests/helpers/resolver', ['exports', 'ember/resolver', '../../config/environment'], function (exports, Resolver, config) {

  'use strict';

  var resolver = Resolver['default'].create();

  resolver.namespace = {
    modulePrefix: config['default'].modulePrefix,
    podModulePrefix: config['default'].podModulePrefix
  };

  exports['default'] = resolver;

});
define('dummy/tests/helpers/resolver.jshint', function () {

  'use strict';

  module('JSHint - helpers');
  test('helpers/resolver.js should pass jshint', function() { 
    ok(true, 'helpers/resolver.js should pass jshint.'); 
  });

});
define('dummy/tests/helpers/start-app', ['exports', 'ember', '../../app', '../../router', '../../config/environment'], function (exports, Ember, Application, Router, config) {

  'use strict';



  exports['default'] = startApp;
  function startApp(attrs) {
    var application;

    var attributes = Ember['default'].merge({}, config['default'].APP);
    attributes = Ember['default'].merge(attributes, attrs); // use defaults, but you can override;

    Ember['default'].run(function () {
      application = Application['default'].create(attributes);
      application.setupForTesting();
      application.injectTestHelpers();
    });

    return application;
  }

});
define('dummy/tests/helpers/start-app.jshint', function () {

  'use strict';

  module('JSHint - helpers');
  test('helpers/start-app.js should pass jshint', function() { 
    ok(true, 'helpers/start-app.js should pass jshint.'); 
  });

});
define('dummy/tests/models/animal.jshint', function () {

  'use strict';

  module('JSHint - models');
  test('models/animal.js should pass jshint', function() { 
    ok(true, 'models/animal.js should pass jshint.'); 
  });

});
define('dummy/tests/models/color.jshint', function () {

  'use strict';

  module('JSHint - models');
  test('models/color.js should pass jshint', function() { 
    ok(true, 'models/color.js should pass jshint.'); 
  });

});
define('dummy/tests/router.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('router.js should pass jshint', function() { 
    ok(true, 'router.js should pass jshint.'); 
  });

});
define('dummy/tests/test-helper', ['./helpers/resolver', 'ember-qunit'], function (resolver, ember_qunit) {

	'use strict';

	ember_qunit.setResolver(resolver['default']);

});
define('dummy/tests/test-helper.jshint', function () {

  'use strict';

  module('JSHint - .');
  test('test-helper.js should pass jshint', function() { 
    ok(true, 'test-helper.js should pass jshint.'); 
  });

});
define('dummy/tests/transforms/array.jshint', function () {

  'use strict';

  module('JSHint - transforms');
  test('transforms/array.js should pass jshint', function() { 
    ok(true, 'transforms/array.js should pass jshint.'); 
  });

});
define('dummy/tests/unit/components/ui-bs-button-choice-test', ['ember-qunit'], function (ember_qunit) {

  'use strict';

  ember_qunit.moduleForComponent("ui-bs-button-choice", "UiBsButtonChoiceComponent", {});

  ember_qunit.test("it renders", function () {
    expect(2);

    // creates the component instance
    var component = this.subject();
    equal(component._state, "preRender");

    // appends the component to the page
    this.append();
    equal(component._state, "inDOM");
  });
  // specify the other units that are required for this test
  // needs: ['component:foo', 'helper:bar']

});
define('dummy/tests/unit/components/ui-bs-button-choice-test.jshint', function () {

  'use strict';

  module('JSHint - unit/components');
  test('unit/components/ui-bs-button-choice-test.js should pass jshint', function() { 
    ok(true, 'unit/components/ui-bs-button-choice-test.js should pass jshint.'); 
  });

});
define('dummy/transforms/array', ['exports', 'ember-data', 'ember'], function (exports, DS, Ember) {

  'use strict';

  exports['default'] = DS['default'].Transform.extend({
    deserialize: function (serialized) {
      return Ember['default'].A(serialized);
    },

    serialize: function (deserialized) {
      return deserialized;
    }
  });

});
/* jshint ignore:start */

define('dummy/config/environment', ['ember'], function(Ember) {
  var prefix = 'dummy';
/* jshint ignore:start */

try {
  var metaName = prefix + '/config/environment';
  var rawConfig = Ember['default'].$('meta[name="' + metaName + '"]').attr('content');
  var config = JSON.parse(unescape(rawConfig));

  return { 'default': config };
}
catch(err) {
  throw new Error('Could not read config from meta tag with name "' + metaName + '".');
}

/* jshint ignore:end */

});

if (runningTests) {
  require("dummy/tests/test-helper");
} else {
  require("dummy/app")["default"].create({"LOG_ACTIVE_GENERATION":true,"LOG_VIEW_LOOKUPS":true});
}

/* jshint ignore:end */
//# sourceMappingURL=dummy.map