import Ember from "ember";
import Pretender from "pretender";

export default Ember.Controller.extend({

	boundArray: ["one", "two", "three"],
	boundHash: [{ id: "one", name: "One", sidecar: "foo" }, { id: "two", name: "Two", sidecar: "bar" }, { id: "three", name: "Three", sidecar: "baz" }],
	selector: "three",
	dynArray: ["one", "two"],
	dynHashArray: [{ id: "1", name: "One" }, { id: "2", name: "Two" }],
	promisedArray: (function () {
		return this.get("store").find("color");
	}).property(),
	promisedObject: (function () {
		return this.get("store").find("animal", "mammal");
	}).property(),
	actions: {
		handleRadioChange: function (change) {
			window.alert("Change to radio control. Current selection is \"%@\". Source was %@.".fmt(change.selected, change.changeSource));
		},
		addArrayElement: function () {
			var current = this.get("dynArray");
			current.addObject(String(current.length + 1));
		},
		removeArrayElement: function () {
			var current = this.get("dynArray");
			if (current.length > 0) {
				this.set("dynArray", current.slice(0, current.length - 1));
			}
		},
		addHashElement: function () {
			var current = this.get("dynHashArray");
			var randomName = function () {
				var randomChoices = ["foo", "bar", "baz", "monkey", "boo", "berry"];
				var seed = Math.floor(Math.random() * (randomChoices.length - 1)) + 1;
				return randomChoices[seed];
			};
			current.addObject({ id: current.length + 1, name: randomName() });
		},
		addSimpleToHashElement: function () {
			var current = this.get("dynHashArray");
			current.addObject(String(current.length + 1));
		},
		removeHashElement: function () {
			var current = this.get("dynHashArray");
			var reduced = current.slice(0, current.length - 1);
			this.set("dynHashArray", reduced);
		}
	},
	server: null,
	startupServer: (function () {
		var self = this;
		var promisedArray = {
			colors: [{ id: "red", name: "Red", group: "primary" }, { id: "blue", name: "Blue", group: "primary" }, { id: "green", name: "Green", group: "primary" }] };
		var promisedObject = { animal: { id: "mammal", examples: ["lion", "bear", "tiger"] } };
		self.set("server", new Pretender(function () {
			this.get("/colors", function (request) {
				return [200, { "Content-Type": "application/json" }, JSON.stringify(promisedArray)];
			}, 5000);
			this.get("/animals/:id", function (request) {
				return [200, { "Content-Type": "application/json" }, JSON.stringify(promisedObject)];
			}, 5000);
		}));
	}).on("init"),
	teardownServer: (function () {
		this.get("server").shutdown();
	}).on("willDestroy")


});